#
# spec file for package plzip
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           plzip
Version:        1.11
Release:        1.3
Summary:        Parallel LZMA Data Compressor
License:        GPL-2.0-or-later
Group:          Productivity/Archiving/Compression
URL:            https://www.nongnu.org/lzip/plzip.html
Source:         https://download.savannah.gnu.org/releases/lzip/plzip/%name-%version.tar.gz
Source2:        https://download.savannah.gnu.org/releases/lzip/plzip/%name-%version.tar.gz.sig
Source3:        %name.keyring
BuildRequires:  c++_compiler
BuildRequires:  lzlib-devel
Requires(post): %install_info_prereq
Requires(preun):%install_info_prereq

%description
Plzip is a parallel version of the lzip data compressor. The files
produced by plzip are fully compatible with lzip-1.4 or newer. Plzip
is intended for faster compression/decompression of big files on
multiprocessor machines.

Lzip is a lossless data compressor based on the LZMA algorithm, with
very safe integrity checking and a user interface similar to the one
of gzip or bzip2. Lzip decompresses almost as fast as gzip and
compresses better than bzip2, which makes it well suited for software
distribution and data archiving.

%prep
%autosetup -p1

%build
mkdir build
pushd build/
# not autoconf
../configure --prefix="%_prefix" --bindir="%_bindir" --datadir="%_datadir" \
	--includedir="%_includedir" --infodir="%_infodir" --libdir="%_libdir" \
	--mandir="%_mandir" --sysconfdir="%_sysconfdir" --enable-shared \
	CFLAGS="%optflags" CXXFLAGS="%optflags"
%make_build
popd

%install
pushd build/
%make_install LDCONFIG=true
popd

%check
pushd build/
%make_build check
popd

%post
%install_info --info-dir="%_infodir" "%_infodir/%name.info%ext_info"

%preun
%install_info_delete --info-dir="%_infodir" "%_infodir/%name.info%ext_info"

%files
%license COPYING
%doc ChangeLog README
%_bindir/plzip
%_infodir/plzip.info*
%_mandir/man1/plzip.1*

%changelog
* Thu Feb  8 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.11
  * The option -o/--output now preserves dates, permissions, and
    ownership of the file when (de)compressing exactly one file.
  * The option -o/--output now creates missing intermediate
    directories when writing to a file.
* Sun Feb 13 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.10
  * In case of error in a numerical argument to a command line
    option, plzip now shows the name of the option and the range
    of valid values.
* Fri Mar 12 2021 Dirk Müller <dmueller@suse.com>
- update to 1.9:
  * main.cc (main): Report an error if a file name is empty.
    Make '-o' behave like '-c', but writing to file instead of stdout.
    Make '-c' and '-o' check whether the output is a terminal only once.
    Do not open output if input is a terminal.
  * main.cc: New option '--check-lib'.
  * Replace 'decompressed', 'compressed' with 'out', 'in' in output.
  * decompress.cc, dec_stream.cc, dec_stdout.cc:
    Continue testing if any input file fails the test.
    Show the largest dictionary size in a multimember file.
  * main.cc: Show final diagnostic when testing multiple files.
  * decompress.cc, dec_stream.cc [LZ_API_VERSION >= 1012]: Avoid
    copying decompressed data when testing with lzlib 1.12 or newer.
  * compress.cc, dec_stream.cc: Start only the worker threads required.
  * dec_stream.cc: Splitter stops reading when trailing data is found.
    Don't include trailing data in the compressed size shown.
    Use plain comparison instead of Boyer-Moore to search for headers.
  * lzip_index.cc: Improve messages for corruption in last header.
  * decompress.cc: Shorten messages 'Data error' and 'Unexpected EOF'.
  * main.cc: Set a valid invocation_name even if argc == 0.
  * Document extraction from tar.lz in manual, '--help', and man page.
  * plzip.texi (Introduction): Mention tarlz as an alternative.
  * plzip.texi: Several fixes and improvements.
  * testsuite: Add 8 new test files.
* Mon Jan  7 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.8
  * No functional changes; just a version bump.
* Fri Dec 14 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.8~rc1
  * The new options '--in-slots' and '--out-slots', setting the
    number of input and output packets buffered during streamed
    decompression, have been added. Increasing the number of
    packets may increase decompression speed, but requires more
    memory.
  * The default number of input packets buffered per worker
    thread when decompressing from non-seekable input has been
    increased from 2 to 4.
  * The default number of output packets buffered per worker
    thread when decompressing to non-seekable output has been
    increased from 32 to 64.
  * Detection of forbidden combinations of characters in trailing
    data has been improved.
* Mon Mar  5 2018 jengelh@inai.de
- Update to new upstream release 1.7
  * The option "--loose-trailing" has been added.
  * The test used by clzip to discriminate trailing data from a
    corrupt header in multimember or concatenated files has been
    improved to a Hamming distance of 3.
* Thu May 11 2017 mpluskal@suse.com
- Update to version 1.6:
  * The option '-l, --list' has been ported from lziprecover.
  * It is now an error to specify two or more different operations
    in the command line (--decompress, --list or --test).
  * In test mode, plzip now continues checking the rest of the
    files if any input file is a terminal.
- Update dependecies and sections for info file handling
* Sat Aug 20 2016 jengelh@inai.de
- Update to new upstream release 1.5
  * The option "-a, --trailing-error", which makes plzip exit with
  error status 2 if any remaining input is detected after
  decompressing the last member, has been added.
  * When decompressing, the file specified with the "--output" option
  is now deleted if the input is a terminal.
* Thu Aug  6 2015 jengelh@inai.de
- Update to new upstream release 1.4
  * The option "-0" has been modified to use the new fast encoder of
  lzlib 1.7, which achieves a compression speed and ratio
  comparable to those of pigz's default compression level.
* Sun Feb  8 2015 jengelh@inai.de
- Update to new upstream release 1.3
  * Testing of a non-seekable file or of standard input now uses up
  to 30 MiB less memory per thread.
  * "-dvvv" and "-tvvv" now show the dictionary size of the first
  member, producing the same output as lzip for single-member
  files.
* Wed Oct  1 2014 jengelh@inai.de
- Update to new upstream release 1.2
  * Copying of file dates, permissions, and ownership now behaves
  like `cp -p`. (If the user ID or the group ID cannot be
  duplicated, the file permission bits S_ISUID and S_ISGID are
  cleared).
  * Individual limits have been set on the number of packets produced
  by each decompresor worker thread to limit the amount of memory
  used in all cases.
  * The license has been changed to GPL version 2 or later.
* Tue Sep 23 2014 jengelh@inai.de
- Drop gpg-offline build-time requirement; this is now handled by
  the local source validator
* Sun Sep 29 2013 jengelh@inai.de
- Update to new upstream release 1.1
  * Plzip now shows the progress of compression at verbosity
  level 2 (-vv).
* Wed Jun  5 2013 jengelh@inai.de
- Update to new upstream release 1.0
  * Scalability of compression (max number of useful worker threads)
  has been increased. Scalability when decompressing from/to
  regular files has been increased.
  * The number of worker threads is now limited to the number of
  members in the input file when decompressing from a regular file.
- Do signature verification
- Wrap description at 70 cols
- Remove redundant %%clean section
* Thu Apr 19 2012 pascal.bleser@opensuse.org
- update to 0.9: minor fixes and cleanup
* Sun Feb 26 2012 pascal.bleser@opensuse.org
- update to 0.8:
  * the option "-F, --recompress", which forces recompression of files whose
    name already has the ".lz" or ".tlz" suffix, has been added
  * the options "-d, --decompress" and "-t, --test" now also show compression
    ratio
  * inability to change output file attributes has been downgraded from error
    to warning
  * quote characters in messages have been changed as advised by GNU Coding
    Standards
* Wed Mar 24 2010 pascal.bleser@opensuse.org
- update to 0.6:
  * some small portability problems have been fixed
  * updates to the manual
* Mon Feb 15 2010 pascal.bleser@opensuse.org
- update to 0.5:
  * parallel decompression has been implemented
* Wed Jan 27 2010 pascal.bleser@opensuse.org
- update to 0.3:
  * the "--data-size" option has been added
  * the output file is now removed if plzip is interrupted
  * this version automatically chooses the smallest possible
    dictionary size for each member during compression, saving
    memory during decompression
  * regular files are now opened in binary mode on non-POSIX
    platforms defining the O_BINARY macro
* Tue Jan 19 2010 pascal.bleser@opensuse.org
- initial version (0.2)
